==> xl-react-components-0.18.103.tgz: package/app/pages/playground/component-navigator/component-navigator.js <==
import R from 'ramda';
import PropTypes from 'prop-types';
import React, {PureComponent} from 'react';
import actions from '../../../xl-react-form/xl-react-dip-redux-form/xl-react-dip-redux-form-actions';
import {XlReactWidgetAutocomplete} from '../../../xl-react-widget/xl-react-widget-autocomplete/xl-react-widget-autocomplete'; // eslint-disable-line max-len
import history from '../../../history';
import {store} from '../../../pages/store/plumbing';

import './component-navigator.less';

export const componentTypes = {
    dip: 'dip',
    form: 'form',
    widget: 'widget'
};

export class ComponentNavigator extends PureComponent {
    static propTypes = {
        componentType: PropTypes.oneOf(R.values(componentTypes)).isRequired,
        state: PropTypes.object.isRequired
    };

    handleSuggestionSelectedForForm(key) {
        const {componentType, state} = this.props;
        const {formId, metadata, model} = state[key];
        store.dispatch(actions.initialize({formId, metadata, model}));
        history.push(`/${componentType}/${key}`);
    }

    handleSuggestionSelected = ({key}) => {
        const {componentType} = this.props;
        if (componentType === 'form') {
            this.handleSuggestionSelectedForForm(key);
        } else {
            history.push(`/${componentType}/${key}`);
        }
    };

    autocompleteHandler = ({value}) => {
        const {state} = this.props;

        return Promise.resolve(
            R.pipe(
                R.keys,
                R.map((key) => ({key, value: state[key].navigationTitle})),
                R.filter((item) => R.includes(R.toLower(value), R.toLower(item.value)))
            )(state)
        );
    };

    autocompleteHandlers = {addCandidates: this.autocompleteHandler};

    render() {
        return <XlReactWidgetAutocomplete
            className="component-navigator"
            handlers={this.autocompleteHandlers}
            objLabel="value"
            onSuggestionSelected={this.handleSuggestionSelected}
        />;
    }
}

==> xl-react-components-0.21.12.tgz: package/app/pages/playground/component-navigator/component-navigator.js <==
import R from 'ramda';
import PropTypes from 'prop-types';
import React, {PureComponent} from 'react';
import actions from '../../../xl-react-form/xl-react-dip-redux-form/xl-react-dip-redux-form-actions';
import {XlReactWidgetAutocomplete} from '../../../xl-react-widget/xl-react-widget-autocomplete/xl-react-widget-autocomplete'; // eslint-disable-line max-len
import history from '../../../history';
import {store} from '../../../pages/store/plumbing';

import './component-navigator.less';

export const componentTypes = {
    dip: 'dip',
    form: 'form',
    widget: 'widget'
};

export class ComponentNavigator extends PureComponent {
    static propTypes = {
        componentType: PropTypes.oneOf(R.values(componentTypes)).isRequired,
        state: PropTypes.object.isRequired
    };

    handleSuggestionSelectedForForm(key) {
        const {componentType, state} = this.props;
        const {formId, metadata, model, validators} = state[key];
        store.dispatch(actions.initialize({formId, metadata, model, validators}));
        history.push(`/${componentType}/${key}`);
    }

    handleSuggestionSelected = ({key}) => {
        const {componentType} = this.props;
        if (componentType === 'form') {
            this.handleSuggestionSelectedForForm(key);
        } else {
            history.push(`/${componentType}/${key}`);
        }
    };

    autocompleteHandler = ({value}) => {
        const {state} = this.props;

        return Promise.resolve(
            R.pipe(
                R.keys,
                R.map((key) => ({key, value: state[key].navigation.title})),
                R.filter((item) => R.includes(R.toLower(value), R.toLower(item.value)))
            )(state)
        );
    };

    autocompleteHandlers = {addCandidates: this.autocompleteHandler};

    render() {
        return <XlReactWidgetAutocomplete
            className="component-navigator"
            handlers={this.autocompleteHandlers}
            objLabel="value"
            onSuggestionSelected={this.handleSuggestionSelected}
        />;
    }
}
